﻿#include "CWindow.h"

#define DIRECTINPUT_VERSION     0x0800          // DirectInputのバージョン指定
#include <dinput.h>

#define DEBUGMODE
#include "debug.h"

// ライブラリリンク
#pragma comment(lib, "dinput8.lib")
#pragma comment(lib, "dxguid.lib")


// グローバル変数定義
CWindow					win;					// ウインドウ
LPDIRECTINPUT8			lpDI = NULL;			// IDirectInput8
LPDIRECTINPUTDEVICE8	lpKeyboard = NULL;		// キーボードデバイス



// メインルーチン
int PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpszCmdParam, int nCmdShow)
{
	INITDEBUG();
	CLEARDEBUG();

	// ウインドウ
	if( !win.Create(hInstance,L"TestDirectInput - ESCで終了") ) {
		DEBUG( "ウィンドウエラー\n" );
 		return -1;
	}

	// IDirectInput8の作成
	HRESULT ret = DirectInput8Create( hInstance,DIRECTINPUT_VERSION,IID_IDirectInput8,(LPVOID*)&lpDI,NULL );
	if( FAILED(ret) ) {
		// 作成に失敗
		DEBUG( "DirectInput8の作成に失敗\n" );
		return -1;
	}

	// IDirectInputDevice8の取得
	ret = lpDI->CreateDevice( GUID_SysKeyboard,&lpKeyboard,NULL );
	if( FAILED(ret) ) {
		DEBUG( "キーボードデバイスの作成に失敗\n" );
		lpDI->Release();
		return -1;
	}

	// 入力データ形式のセット
	ret = lpKeyboard->SetDataFormat( &c_dfDIKeyboard );
	if( FAILED(ret) ) {
		DEBUG( "入力データ形式のセット失敗\n" );
		lpKeyboard->Release();
		lpDI->Release();
		return -1;
	}

	// 排他制御のセット
	ret = lpKeyboard->SetCooperativeLevel( win.hWnd,DISCL_FOREGROUND|DISCL_NONEXCLUSIVE|DISCL_NOWINKEY );
	if( FAILED(ret) ) {
		DEBUG( "排他制御のセット失敗\n" );
		lpKeyboard->Release();
		lpDI->Release();
		return -1;
	}

	// 動作開始
	lpKeyboard->Acquire();

	MSG msg;
	while(1) {
		if( PeekMessage(&msg,NULL,0,0,PM_REMOVE) ) {
			if( msg.message==WM_QUIT ) {
				DEBUG( "WM_QUIT\n" );
				break;
			}
			TranslateMessage(&msg);
        	DispatchMessage(&msg);
		}

		// キーの入力
		BYTE key[256];
		ZeroMemory( key,sizeof(key) );
		ret = lpKeyboard->GetDeviceState( sizeof(key),key );
		if( FAILED(ret) ) {
			// 失敗なら再開させてもう一度取得
			lpKeyboard->Acquire();
			lpKeyboard->GetDeviceState( sizeof(key),key );
		}

		// ESCAPEなら終了
		if( key[DIK_ESCAPE]&0x80 )
			break;

		Sleep(8);										// CPUへのウエイト
	}

	lpKeyboard->Release();
	lpDI->Release();

	win.Delete();

	return 0;
}
